From: Michael Walle <michael@walle.cc>
To: linux-mtd@lists.infradead.org, linux-kernel@vger.kernel.org
Cc: Tudor Ambarus <tudor.ambarus@microchip.com>,
Pratyush Yadav <p.yadav@ti.com>,
Miquel Raynal <miquel.raynal@bootlin.com>,
Richard Weinberger <richard@nod.at>,
Vignesh Raghavendra <vigneshr@ti.com>,
yaliang.wang@windriver.com, Michael Walle <michael@walle.cc>
Subject: [PATCH v5 11/32] mtd: spi-nor: micron-st: unify function names
Date: Wed, 23 Feb 2022 14:43:37 +0100 [thread overview]
Message-ID: <20220223134358.1914798-12-michael@walle.cc> (raw)
In-Reply-To: <20220223134358.1914798-1-michael@walle.cc>
To avoid name clashes unify all the function and static object names and
use one of the following prefixes which should be sufficiently unique:
- <vendor>_nor_
- <flash_family>_nor_
- <flash_part>_
There are no functional changes.
Signed-off-by: Michael Walle <michael@walle.cc>
Acked-by: Pratyush Yadav <p.yadav@ti.com>
---
drivers/mtd/spi-nor/micron-st.c | 34 ++++++++++++++++-----------------
1 file changed, 17 insertions(+), 17 deletions(-)
diff --git a/drivers/mtd/spi-nor/micron-st.c b/drivers/mtd/spi-nor/micron-st.c
index bb95b1aabf74..7a68f2ad3ea1 100644
--- a/drivers/mtd/spi-nor/micron-st.c
+++ b/drivers/mtd/spi-nor/micron-st.c
@@ -17,7 +17,7 @@
#define SPINOR_MT_OCT_DTR 0xe7 /* Enable Octal DTR. */
#define SPINOR_MT_EXSPI 0xff /* Enable Extended SPI (default) */
-static int spi_nor_micron_octal_dtr_enable(struct spi_nor *nor, bool enable)
+static int micron_st_nor_octal_dtr_enable(struct spi_nor *nor, bool enable)
{
struct spi_mem_op op;
u8 *buf = nor->bouncebuf;
@@ -102,7 +102,7 @@ static int spi_nor_micron_octal_dtr_enable(struct spi_nor *nor, bool enable)
static void mt35xu512aba_default_init(struct spi_nor *nor)
{
- nor->params->octal_dtr_enable = spi_nor_micron_octal_dtr_enable;
+ nor->params->octal_dtr_enable = micron_st_nor_octal_dtr_enable;
}
static void mt35xu512aba_post_sfdp_fixup(struct spi_nor *nor)
@@ -130,7 +130,7 @@ static const struct spi_nor_fixups mt35xu512aba_fixups = {
.post_sfdp = mt35xu512aba_post_sfdp_fixup,
};
-static const struct flash_info micron_parts[] = {
+static const struct flash_info micron_nor_parts[] = {
{ "mt35xu512aba", INFO(0x2c5b1a, 0, 128 * 1024, 512)
FLAGS(USE_FSR)
NO_SFDP_FLAGS(SECT_4K | SPI_NOR_OCTAL_READ |
@@ -143,7 +143,7 @@ static const struct flash_info micron_parts[] = {
FIXUP_FLAGS(SPI_NOR_4B_OPCODES) },
};
-static const struct flash_info st_parts[] = {
+static const struct flash_info st_nor_parts[] = {
{ "n25q016a", INFO(0x20bb15, 0, 64 * 1024, 32)
NO_SFDP_FLAGS(SECT_4K | SPI_NOR_QUAD_READ) },
{ "n25q032", INFO(0x20ba16, 0, 64 * 1024, 64)
@@ -250,15 +250,15 @@ static const struct flash_info st_parts[] = {
};
/**
* st_micron_set_4byte_addr_mode() - Set 4-byte address mode for ST and Micron
* flashes.
* @nor: pointer to 'struct spi_nor'.
* @enable: true to enter the 4-byte address mode, false to exit the 4-byte
* address mode.
*
* Return: 0 on success, -errno otherwise.
*/
-static int st_micron_set_4byte_addr_mode(struct spi_nor *nor, bool enable)
+static int micron_st_nor_set_4byte_addr_mode(struct spi_nor *nor, bool enable)
{
int ret;
@@ -273,28 +273,28 @@ static int st_micron_set_4byte_addr_mode(struct spi_nor *nor, bool enable)
return spi_nor_write_disable(nor);
}
-static void micron_st_default_init(struct spi_nor *nor)
+static void micron_st_nor_default_init(struct spi_nor *nor)
{
nor->flags |= SNOR_F_HAS_LOCK;
nor->flags &= ~SNOR_F_HAS_16BIT_SR;
nor->params->quad_enable = NULL;
- nor->params->set_4byte_addr_mode = st_micron_set_4byte_addr_mode;
+ nor->params->set_4byte_addr_mode = micron_st_nor_set_4byte_addr_mode;
}
-static const struct spi_nor_fixups micron_st_fixups = {
- .default_init = micron_st_default_init,
+static const struct spi_nor_fixups micron_st_nor_fixups = {
+ .default_init = micron_st_nor_default_init,
};
const struct spi_nor_manufacturer spi_nor_micron = {
.name = "micron",
- .parts = micron_parts,
- .nparts = ARRAY_SIZE(micron_parts),
- .fixups = µn_st_fixups,
+ .parts = micron_nor_parts,
+ .nparts = ARRAY_SIZE(micron_nor_parts),
+ .fixups = µn_st_nor_fixups,
};
const struct spi_nor_manufacturer spi_nor_st = {
.name = "st",
- .parts = st_parts,
- .nparts = ARRAY_SIZE(st_parts),
- .fixups = µn_st_fixups,
+ .parts = st_nor_parts,
+ .nparts = ARRAY_SIZE(st_nor_parts),
+ .fixups = µn_st_nor_fixups,
};
@@ -250,15 +250,15 @@ static const struct flash_info st_parts[] = {
};
/**
- * st_micron_set_4byte_addr_mode() - Set 4-byte address mode for ST and Micron
- * flashes.
+ * micron_st_nor_set_4byte_addr_mode() - Set 4-byte address mode for ST and
+ * Micron flashes.
* @nor: pointer to 'struct spi_nor'.
* @enable: true to enter the 4-byte address mode, false to exit the 4-byte
--
2.30.2
______________________________________________________
Linux MTD discussion mailing list
http://lists.infradead.org/mailman/listinfo/linux-mtd/
next prev parent reply other threads:[~2022-02-23 13:51 UTC|newest]
Thread overview: 44+ messages / expand[flat|nested] mbox.gz Atom feed top
2022-02-23 13:43 [PATCH v5 00/32] mtd: spi-nor: move vendor specific code into vendor modules Michael Walle
2022-02-23 13:43 ` [PATCH v5 01/32] mtd: spi-nor: atmel: unify function names Michael Walle
2022-02-23 13:43 ` [PATCH v5 02/32] mtd: spi-nor: catalyst: " Michael Walle
2022-02-23 13:43 ` [PATCH v5 03/32] mtd: spi-nor: eon: " Michael Walle
2022-02-23 13:43 ` [PATCH v5 04/32] mtd: spi-nor: esmt: " Michael Walle
2022-02-23 13:43 ` [PATCH v5 05/32] mtd: spi-nor: everspin: " Michael Walle
2022-02-23 13:43 ` [PATCH v5 06/32] mtd: spi-nor: fujitsu: " Michael Walle
2022-02-23 13:43 ` [PATCH v5 07/32] mtd: spi-nor: gigadevice: " Michael Walle
2022-02-23 13:43 ` [PATCH v5 08/32] mtd: spi-nor: intel: " Michael Walle
2022-02-23 13:43 ` [PATCH v5 09/32] mtd: spi-nor: issi: " Michael Walle
2022-02-23 13:43 ` [PATCH v5 10/32] mtd: spi-nor: macronix: " Michael Walle
2022-02-23 13:43 ` Michael Walle [this message]
2022-02-25 13:35 ` [PATCH v5 11/32] mtd: spi-nor: micron-st: " Tudor.Ambarus
2022-02-25 13:36 ` Tudor.Ambarus
2022-02-25 15:36 ` Tudor.Ambarus
2022-02-23 13:43 ` [PATCH v5 12/32] mtd: spi-nor: spansion: " Michael Walle
2022-02-23 13:43 ` [PATCH v5 13/32] mtd: spi-nor: sst: " Michael Walle
2022-02-23 13:43 ` [PATCH v5 14/32] mtd: spi-nor: winbond: " Michael Walle
2022-02-23 13:43 ` [PATCH v5 15/32] mtd: spi-nor: xilinx: " Michael Walle
2022-02-23 13:43 ` [PATCH v5 16/32] mtd: spi-nor: xmc: " Michael Walle
2022-02-23 13:43 ` [PATCH v5 17/32] mtd: spi-nor: slightly refactor the spi_nor_setup() Michael Walle
2022-02-23 13:43 ` [PATCH v5 18/32] mtd: spi-nor: allow a flash to define its own ready() function Michael Walle
2022-02-23 13:43 ` [PATCH v5 19/32] mtd: spi-nor: export more function to be used in vendor modules Michael Walle
2022-02-23 13:43 ` [PATCH v5 20/32] mtd: spi-nor: guard _page_size parameter in S3AN_INFO() Michael Walle
2022-02-23 13:43 ` [PATCH v5 21/32] mtd: spi-nor: move all xilinx specifics into xilinx.c Michael Walle
2022-02-23 13:43 ` [PATCH v5 22/32] mtd: spi-nor: xilinx: rename vendor specific functions and defines Michael Walle
2022-02-25 14:02 ` Tudor.Ambarus
2022-02-23 13:43 ` [PATCH v5 23/32] mtd: spi-nor: xilinx: correct the debug message Michael Walle
2022-02-23 13:43 ` [PATCH v5 24/32] mtd: spi-nor: move all micron-st specifics into micron-st.c Michael Walle
2022-02-23 13:43 ` [PATCH v5 25/32] mtd: spi-nor: micron-st: convert USE_FSR to a manufacturer flag Michael Walle
2022-02-23 13:43 ` [PATCH v5 26/32] mtd: spi-nor: micron-st: rename vendor specific functions and defines Michael Walle
2022-02-23 14:56 ` Pratyush Yadav
2022-02-25 14:03 ` Tudor.Ambarus
2022-02-25 15:36 ` Michael Walle
2022-02-25 15:38 ` Tudor.Ambarus
2022-02-23 13:43 ` [PATCH v5 27/32] mtd: spi-nor: spansion: slightly rework control flow in late_init() Michael Walle
2022-02-23 13:43 ` [PATCH v5 28/32] mtd: spi-nor: move all spansion specifics into spansion.c Michael Walle
2022-02-23 13:43 ` [PATCH v5 29/32] mtd: spi-nor: spansion: convert USE_CLSR to a manufacturer flag Michael Walle
2022-02-23 13:43 ` [PATCH v5 30/32] mtd: spi-nor: spansion: rename vendor specific functions and defines Michael Walle
2022-02-25 14:07 ` Tudor.Ambarus
2022-02-23 13:43 ` [PATCH v5 31/32] mtd: spi-nor: slightly change code style in spi_nor_sr_ready() Michael Walle
2022-02-25 14:08 ` Tudor.Ambarus
2022-02-23 13:43 ` [PATCH v5 32/32] mtd: spi-nor: renumber flags Michael Walle
2022-02-25 16:18 ` [PATCH v5 00/32] mtd: spi-nor: move vendor specific code into vendor modules Tudor Ambarus
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20220223134358.1914798-12-michael@walle.cc \
--to=michael@walle.cc \
--cc=linux-kernel@vger.kernel.org \
--cc=linux-mtd@lists.infradead.org \
--cc=miquel.raynal@bootlin.com \
--cc=p.yadav@ti.com \
--cc=richard@nod.at \
--cc=tudor.ambarus@microchip.com \
--cc=vigneshr@ti.com \
--cc=yaliang.wang@windriver.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox